@@ -99,3 +99,19 @@ class InlinePaginationKeyboard(InlineKeyboardMarkup):
     @property
     def markup(self):
         self.inline_keyboard.append(self.build_pagination)
+
+
+class InlineButton(InlineKeyboardButton):
+    def __init__(self, text=None, callback_data=None, url=None,
+                 login_url=None, user_id=None, switch_inline_query=None,
+                 switch_inline_query_current_chat=None, callback_game=None):
+        super().__init__(
+            text=text,
+            callback_data=callback_data,
+            url=url,
+            login_url=login_url,
+            user_id=user_id,
+            switch_inline_query=switch_inline_query,
+            switch_inline_query_current_chat=switch_inline_query_current_chat,
+            callback_game=callback_game
+        )
